'''
Created on May 14, 2013

@author: moschlar
'''

import tw2.core as twc
import tw2.jquery as twj
import tw2.bootstrap.forms as twbf

from tw2.wysihtml5.widgets import wysihtml5_js

__all__ = ['Wysihtml5']


bootstrap_wysihtml5_js = twc.JSLink(
    filename='static/bootstrap-wysihtml5.js',
    resources=[twj.jquery_js, twbf.bootstrap_js, wysihtml5_js],
    location='headbottom')

bootstrap_wysihtml5_css = twc.CSSLink(
    filename='static/bootstrap-wysihtml5.css',
    resources=[twbf.bootstrap_css])


class Wysihtml5(twbf.TextArea):
    resources = [bootstrap_wysihtml5_js, bootstrap_wysihtml5_css]

    # TODO: Color support
    # Explicitly disable stylesheets, because wysiwyg-color.css is fetched otherwise
    stylesheets = twc.Param(default=list())
    wysihtml5_args = twc.Param(default=dict())

    def prepare(self):
        super(Wysihtml5, self).prepare()
        self.add_call(twj.jQuery(self.selector).wysihtml5(dict(
            stylesheets=self.stylesheets,
            **self.wysihtml5_args
        )))



import tw2.core as twc
import tw2.forms as twf


__all__ = [
    'Wysihtml5'
]

wysihtml5_js = twc.JSLink(
    filename='static/wysihtml5.js',
    location='headbottom')
wysihtml5_editor_css = twc.CSSLink(
    filename='static/editor.css')

wysihtml5_parser_simple = twc.JSLink(
    filename='static/simple.js',
    location='headbottom')
wysihtml5_parser_advanced = twc.JSLink(
    filename='static/advanced.js',
    location='headbottom')
parsers = dict(simple=wysihtml5_parser_simple,
    advanced=wysihtml5_parser_advanced)


class Wysihtml5(twf.TextArea):
    template = "mako:tw2.wysihtml5.templates.wysihtml5"

    resources = [
        wysihtml5_js
    ]

    parser = twc.Param(
        'The set of parser rules to use. '
        'The simple parser contains only basic html5 tags, while the '
        'advanced parser contains more html5 tags and preserves some '
        'css classes. If you use the simple parser, the editor css is '
        'not strictly needed.',
        default='advanced')
    toolbar_id = twc.Variable(
        default='wysihtml5-toolbar')

    def prepare(self):
        super(Wysihtml5, self).prepare()
        if not hasattr(self, 'id') or 'id' not in self.attrs:
            raise ValueError('WYSIHTML5 must be supplied an id')

        self.resources.append(parsers[self.parser])
        self.toolbar_id = self.compound_id + '-toolbar'
        self.resources.append(twc.JSSource(src="""
var editor = new wysihtml5.Editor("%s", {
    toolbar:  "%s",
    parserRules:  wysihtml5ParserRules,
    stylesheets: ["/resources/%s/%s"]
});
""" % (self.compound_id, self.toolbar_id,
        wysihtml5_editor_css.guess_modname(), wysihtml5_editor_css.filename)))



from setuptools import setup, find_packages

setup(
    name='tw2.wysihtml5',
    version='0.3',
    description='WYSIHTML5 widget for ToscaWidgets2',
    author='Moritz Schlarb',
    author_email='moschlar@metalabs.de',
    url='https://github.com/toscawidgets/tw2.wysihtml5',
    license='BSD 2-clause',
    install_requires=[
        "tw2.core",
        "tw2.forms",
        "Mako",
        ## Add other requirements here
        # "Genshi",
        ],
    extras_require={'bootstrap': 'tw2.bootstrap.forms'},
    packages=find_packages(exclude=['ez_setup', 'tests']),
    namespace_packages=['tw2', 'tw2.bootstrap'],
    zip_safe=False,
    include_package_data=True,
    test_suite='nose.collector',
    entry_points="""
        [tw2.widgets]
        # Register your widgets so they can be listed in the WidgetBrowser
        widgets_plain = tw2.wysihtml5
        widgets_bootstrap = tw2.bootstrap.wysihtml5
    """,
    keywords=[
        'toscawidgets.widgets',
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Environment :: Web Environment :: ToscaWidgets',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development :: Widget Sets',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'License :: OSI Approved :: BSD License',
    ],
)
